@@ -66,7 +66,11 @@ class AlgorithmClient(BaseClient):
     #
 
     def list_algorithms(self):
-        params = {"teamId": self.user["teamId"]}
+        team_id = self.team_id
+        if team_id is None:
+            team_id = self.user["teamId"]
+
+        params = {"teamId": team_id}
         return self.session.request("get", "baas", "/api/Algorithms/getList", params=params)
 
     def list_environments(self, algorithm_id):
