@@ -1,6 +1,7 @@
 import os
 import requests
 
+from alfa_sdk.common.utils import append_cookie
 from alfa_sdk.common.helpers import EndpointHelper
 from alfa_sdk.common.stores import AuthStore
 from alfa_sdk.common.exceptions import (
@@ -11,6 +12,7 @@ from alfa_sdk.common.exceptions import (
 
 
 ALFA_APP_ID = 30
+NEO_SESSION_ID_KEY = "SESSIONID"
 
 
 class Authentication:
@@ -18,11 +20,15 @@ class Authentication:
     token = None
     cookie = None
 
-    def __init__(self, credentials={}, *, alfa_env, alfa_id=None, region=None):
+    def __init__(self, credentials={}, *, alfa_env, alfa_id=None, region=None, context={}):
         endpoint = EndpointHelper(alfa_env=alfa_env, alfa_id=alfa_id, region=region)
         url_core = endpoint.resolve("core")
         self._authenticate(url_core, credentials)
 
+        self.cookie = append_cookie(
+            self.cookie, NEO_SESSION_ID_KEY, context.get("neoSessionId", None)
+        )
+
     def _authenticate(self, url_core, credentials):
         if "client_id" in credentials and "client_secret" in credentials:
             self._request_and_set_token(url_core, credentials)
@@ -35,7 +41,7 @@ class Authentication:
                 self.user = validate_token(url_core, token, cookie)
                 self.cookie = cookie
                 self.token = token
-            except:
+            except Exception:
                 self._request_and_set_token(url_core, credentials)
 
     def _request_and_set_token(self, url_core, credentials):
