@@ -17,7 +17,7 @@ class EndpointHelper:
         resource_path = "/".join(("common", "data", "endpoints.json"))
         file = pkg_resources.resource_string("alfa_sdk", resource_path)
 
-        self.alfa_env = alfa_env
+        self.alfa_env = EndpointHelper.resolve_environment(alfa_env)
         self.alfa_id = alfa_id or "public"
         self.region = region or "eu-central-1"
 
@@ -26,7 +26,7 @@ class EndpointHelper:
         self.hostname = data["hostname"]
         self.domain = data["domain"]
 
-    def resolve(self, service, path=""):
+    def resolve(self, service, path="", *, environment=None):
         if service not in self.services:
             known_services = ", ".join(sorted(self.services.keys()))
             raise UnknownServiceError(service_name=service, known_service_names=known_services)
@@ -34,7 +34,9 @@ class EndpointHelper:
         if self.alfa_env not in self.services[service]:
             raise ServiceEnvironmentError(service_name=service, environment=self.alfa_env)
 
-        host = self.services[service][self.alfa_env]
+        environment = environment if environment is not None else self.alfa_env
+        environment = EndpointHelper.resolve_environment(environment)
+        host = self.services[service][environment]
         protocol = "https"
         if isinstance(host, list):
             protocol, host = host
@@ -44,6 +46,19 @@ class EndpointHelper:
         )
         return "{}{}".format(base_url, path)
 
+    @staticmethod
+    def resolve_environment(env):
+        env = env.lower()
+
+        if env.startswith("prod"):
+            return "prod"
+        if env.startswith("test"):
+            return "test"
+        if env.startswith("dev"):
+            return "dev"
+
+        return env
+
 
 class VersionHelper:
     @staticmethod
