@@ -29,7 +29,7 @@ class Session:
 
         alfa_config = {"alfa_env": self.alfa_env, "alfa_id": self.alfa_id, "region": self.region}
         self.endpoint = EndpointHelper(**alfa_config)
-        self.auth = Authentication(credentials, **alfa_config)
+        self.auth = Authentication(credentials, **alfa_config, context=self.context)
 
         options = self.auth.authenticate_request({})
         self.http_session = requests.Session()
@@ -66,7 +66,7 @@ class Session:
         path = "{}{}".format(str(prefix), str(path))
         url = self.endpoint.resolve(service, path, environment=environment)
         kwargs = filter_arguments({**self.default_options, **kwargs})
-        
+
         res = self.http_session.request(method, url, **kwargs)
         if parse:
             return parse_response(res)
@@ -74,6 +74,8 @@ class Session:
             return res
 
     def invoke(self, function_id, environment, problem, **kwargs):
+        function_type = kwargs.pop("function_type", "algorithm")
+
         if type(problem) is not dict:
             try:
                 problem = json.loads(problem)
@@ -82,8 +84,6 @@ class Session:
 
         #
 
-        function_type = kwargs.get("function_type", "algorithm")
-
         if function_type == "algorithm":
             return self.invoke_algorithm(function_id, environment, problem, **kwargs)
         elif function_type == "integration":
@@ -92,9 +92,9 @@ class Session:
         raise ValidationError(error="Unknown type of release provided.")
 
     def invoke_algorithm(self, algorithm_id, environment, problem, **kwargs):
-        return_holding_response = kwargs.get("return_holding_response")
-        include_details = kwargs.get("include_details")
-        can_buffer = kwargs.get("can_buffer")
+        return_holding_response = kwargs.pop("return_holding_response", None)
+        include_details = kwargs.pop("include_details", None)
+        can_buffer = kwargs.pop("can_buffer", None)
 
         #
 
@@ -106,17 +106,27 @@ class Session:
             "includeDetails": include_details,
             "canBuffer": can_buffer,
         }
-        return self.request("post", "baas", "/api/Algorithms/submitRequest", json=body)
+        return self.request(
+            method="post",
+            service="baas",
+            path="/api/Algorithms/submitRequest",
+            json=body,
+            **kwargs,
+        )
 
     def invoke_integration(self, integration_id, environment, problem, **kwargs):
-        function_name = kwargs.get("function_name")
+        function_name = kwargs.pop("function_name", None)
+
+        #
+
         return self.request(
-            "post",
-            "ais",
-            "/api/Integrations/{}/environments/{}/functions/{}/invoke".format(
+            method="post",
+            service="ais",
+            path="/api/Integrations/{}/environments/{}/functions/{}/invoke".format(
                 integration_id, environment, function_name
             ),
             json=problem,
+            **kwargs,
         )
 
 
