@@ -1,6 +1,3 @@
-from os import environ
-
-
 def format_function_id(team_id, function_id):
     if team_id is None:
         return function_id
@@ -39,3 +36,18 @@ def split_environment_id(environment_id):
         [team_id, function_id, environment_name] = parts
 
     return team_id, function_id, environment_name
+
+
+def append_cookie(cookie, key, value):
+    if key is None or value is None:
+        return cookie
+
+    if cookie is None:
+        cookie = ""
+
+    cookies = [string.strip() for string in cookie.split(";")]
+    cookies = [string for string in cookies if string != ""]
+    cookies = [string for string in cookies if not string.startswith("{}=".format(key))]
+
+    cookies.append("{}={}".format(key, value))
+    return "; ".join(cookies)
