@@ -7,19 +7,22 @@ class DataClient(BaseClient):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-    def fetch_data_file(self, data_file_id):
-        url = self.session.request(
-            "get", "data", "/api/Storages/download/{}".format(data_file_id)
+        self.session.set_default(
+            {
+                "service": "data",
+                "prefix": "/api/storages",
+            }
         )
 
+    def fetch_data_file(self, data_file_id):
+        url = self.session.request("get", path="/download/{}".format(data_file_id))
         res = requests.get(url["downloadLink"], allow_redirects=True)
         return res.content
 
     def list_data_files(self, prefix="", skip=0, limit=100, order="name ASC"):
         return self.session.request(
             "get",
-            "data",
-            "/api/Storages/list",
+            path="/list",
             params={
                 "prefix": prefix,
                 "skip": skip,
@@ -32,7 +35,6 @@ class DataClient(BaseClient):
     def update_data_file(self, data_file_id, changes):
         return self.session.request(
             "put",
-            "data",
-            "/api/Storages/update/{}".format(data_file_id),
+            path="/update/{}".format(data_file_id),
             json={"updates": changes},
         )
