@@ -2,7 +2,7 @@ import os
 import requests
 
 from alfa_sdk.common.base import BaseResource
-from alfa_sdk.common.exceptions import ResourceNotFoundError, AlfaError
+from alfa_sdk.common.exceptions import ResourceError, AlfaError
 from alfa_sdk import resources
 
 
@@ -41,6 +41,9 @@ class MetaUnit(BaseResource):
     def get_environment(self):
         return resources.AlgorithmEnvironment(self.environment_id, session=self.session)
 
+    def get_active_instance_from_server(self, body):
+        return self.session.request("get", "meta", "/api/Units/getActiveInstance", json=body)
+
     def get_active_instance(self):
         if self.local:
             instances = self.list_instances()
@@ -49,7 +52,11 @@ class MetaUnit(BaseResource):
                 return LocalMetaInstance(active_instance["path"])
 
         body = {"algorithmEnvironmentId": self.environment_id, "tag": self.tag}
-        data = self.session.request("get", "meta", "/api/Units/getActiveInstance", json=body)
+        data = self.get_active_instance_from_server(body)
+        
+        if not isinstance(data, dict):
+            raise ResourceError(resource='meta instance', error='There are no active instances.')
+            
         return MetaInstance(data["id"], data=data, session=self.session)
 
     def list_instances(self):
